# 自己常用的代码封装了一下

## pip安装
```sh
pip3 install RookieTools
```

## 源码安装
> 源码安装我就测试了 Linux Arch 操作系统  
> 其他系统未测试

```sh

git clone https://github.com/hyll8882019/RookieTools.git
cd RookieTools
python3 setup.py build
python3 setup.py install
```

[更新日志](CHANGELOG.md)